import axios from "axios";
import { ScoresaberPlayer } from "./models/PlayerModel";
import { ScoresaberPlayerSearch } from "./models/ScoresaberPlayerSearch";

const CONSTS = {
	BASE_URL: "https://scoresaber.com/api",
	PLAYER_COUNT: "players/count",
	PLAYERS: "players",
	PLAYER: "player/{playerId}",
};

enum PlayerDataType {
	BASIC = "basic",
	FULL = "full",
	SCORES = "scores",
}

// Player API
// ---------

/**
 * Gets players based on the search query, page, and countries
 *
 * @param search the search query
 * @param page the page number
 * @param countries the countries to search
 * @param withMetadata whether to include metadata
 * @returns {ScoresaberPlayerSearch} the players
 */
export async function getPlayers(
	search: string,
	page: number,
	countries: string[],
	withMetadata: boolean = true
): Promise<ScoresaberPlayerSearch> {
	const url = `${CONSTS.BASE_URL}/${
		CONSTS.PLAYERS
	}?search=${search}&page=${page}&countries=${countries.join(
		","
	)}&withMetadata=${withMetadata}`;
	const response = await axios.get(url);
	return response.data;
}

/**
 * Gets the number of active players on ScoreSaber
 *
 * @returns {number} the number of active players
 */
export async function getActivePlayerCount(): Promise<number> {
	const url = `${CONSTS.BASE_URL}/${CONSTS.PLAYER_COUNT}`;
	const response = await axios.get(url);
	return response.data;
}

/**
 * Gets a players player data from ScoreSaber
 *
 * @param playerId the players id (not the name)
 * @param type the type of data to get
 * @returns {ScoresaberPlayer} the player data
 */
export async function getPlayer(
	playerId: string,
	type: PlayerDataType = PlayerDataType.BASIC
): Promise<ScoresaberPlayer> {
	const url = `${CONSTS.BASE_URL}/${CONSTS.PLAYER.replace(
		"{playerId}",
		playerId
	)}/${type}`;
	const response = await axios.get(url);
	return response.data;
}

// Leaderboard API
// ---------

export default {
	// Player API
	getPlayers,
	getActivePlayerCount,
	getPlayer,

	// Leaderboard API
};
